@@ -43,7 +43,7 @@ void initRCCIconTheme()
 {
     const QString iconThemeRcc = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("icontheme.rcc"));
     if (!iconThemeRcc.isEmpty()) {
-        const QString iconThemeName = QStringLiteral("kf5_rcc_theme");
+        const QString iconThemeName = QStringLiteral("kf6_rcc_theme");
         const QString iconSubdir = QStringLiteral("/icons/") + iconThemeName;
         if (QResource::registerResource(iconThemeRcc, iconSubdir)) {
             if (QFileInfo::exists(QLatin1Char(':') + iconSubdir + QStringLiteral("/index.theme"))) {
@@ -84,7 +84,9 @@ static void setBreezeFallback()
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 }
 
+#ifndef Q_OS_ANDROID
 Q_COREAPP_STARTUP_FUNCTION(setBreezeFallback)
+#endif
 class KIconThemeDir;
 class KIconThemePrivate
 {
@@ -112,12 +114,12 @@ public:
     QString mDir, mName, mInternalName, mDesc;
     QStringList mInherits;
     QStringList mExtensions;
-    QVector<KIconThemeDir *> mDirs;
-    QVector<KIconThemeDir *> mScaledDirs;
+    QList<KIconThemeDir *> mDirs;
+    QList<KIconThemeDir *> mScaledDirs;
     bool followsColorScheme : 1;
 
     /// Searches the given dirs vector for a matching icon
-    QString iconPath(const QVector<KIconThemeDir *> &dirs, const QString &name, int size, qreal scale, KIconLoader::MatchType match) const;
+    QString iconPath(const QList<KIconThemeDir *> &dirs, const QString &name, int size, qreal scale, KIconLoader::MatchType match) const;
 };
 Q_GLOBAL_STATIC(QString, _theme)
 Q_GLOBAL_STATIC(QStringList, _theme_list)
@@ -184,7 +186,7 @@ private:
     const QString mThemeDir;
 };
 
-QString KIconThemePrivate::iconPath(const QVector<KIconThemeDir *> &dirs, const QString &name, int size, qreal scale, KIconLoader::MatchType match) const
+QString KIconThemePrivate::iconPath(const QList<KIconThemeDir *> &dirs, const QString &name, int size, qreal scale, KIconLoader::MatchType match) const
 {
     QString path;
     QString tempPath; // used to cache icon path if it exists
@@ -249,6 +251,10 @@ QString KIconThemePrivate::iconPath(const QVector<KIconThemeDir *> &dirs, const
             if ((abs(dw) >= abs(delta)) && ((dw < 0) || (delta > 0))) {
                 continue;
             }
+
+            if (match == KIconLoader::MatchBestOrGreaterSize && dw < 0) {
+                continue;
+            }
         }
 
         // cache the result of iconPath() call which checks if file exists
@@ -483,7 +489,7 @@ QStringList KIconTheme::queryIcons(int size, KIconLoader::Context context) const
 {
     // Try to find exact match
     QStringList result;
-    const QVector<KIconThemeDir *> listDirs = d->mDirs + d->mScaledDirs;
+    const QList<KIconThemeDir *> listDirs = d->mDirs + d->mScaledDirs;
     for (const KIconThemeDir *dir : listDirs) {
         if (!isAnyOrDirContext(dir, context)) {
             continue;
@@ -675,51 +681,6 @@ QString KIconTheme::defaultThemeName()
     return QStringLiteral("hicolor");
 }
 
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 64)
-void KIconTheme::assignIconsToContextMenu(ContextMenus type, QList<QAction *> actions)
-{
-    switch (type) {
-    // FIXME: This code depends on Qt's action ordering.
-    case TextEditor:
-        enum {
-            UndoAct,
-            RedoAct,
-            Separator1,
-            CutAct,
-            CopyAct,
-            PasteAct,
-            DeleteAct,
-            ClearAct,
-            Separator2,
-            SelectAllAct,
-            NCountActs,
-        };
-
-        if (actions.count() < NCountActs) {
-            return;
-        }
-
-        actions[UndoAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
-        actions[RedoAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-redo")));
-        actions[CutAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-cut")));
-        actions[CopyAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
-        actions[PasteAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-paste")));
-        actions[ClearAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear")));
-        actions[DeleteAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-        actions[SelectAllAct]->setIcon(QIcon::fromTheme(QStringLiteral("edit-select-all")));
-        break;
-
-    case ReadOnlyText:
-        if (actions.count() < 1) {
-            return;
-        }
-
-        actions[0]->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
-        break;
-    }
-}
-#endif
-
 /*** KIconThemeDir ***/
 
 KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, const KConfigGroup &config)
@@ -737,10 +698,6 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         mContext = KIconLoader::Device;
     } else if (tmp == QLatin1String("MimeTypes")) {
         mContext = KIconLoader::MimeType;
-#if KICONTHEMES_BUILD_DEPRECATED_SINCE(4, 8)
-    } else if (tmp == QLatin1String("FileSystems")) {
-        mContext = KIconLoader::FileSystem;
-#endif
     } else if (tmp == QLatin1String("Applications")) {
         mContext = KIconLoader::Application;
     } else if (tmp == QLatin1String("Actions")) {
